@@ -8,6 +8,8 @@ import tkinter.ttk as ttk
 
 import dftbplus_step
 
+import seamm_widgets as sw
+
 logger = logging.getLogger(__name__)
 
 
@@ -71,7 +73,25 @@ class TkOptimization(dftbplus_step.TkEnergy):
         )
 
         for key in dftbplus_step.OptimizationParameters.parameters:
-            self[key] = P[key].widget(opt_frame)
+            if key not in ("structure handling", "configuration name"):
+                self[key] = P[key].widget(opt_frame)
+
+        self["optimization method"].bind("<<ComboboxSelected>>", self.reset_dialog)
+        self["optimization method"].bind("<Return>", self.reset_dialog)
+        self["optimization method"].bind("<FocusOut>", self.reset_dialog)
+
+        # Create the structure-handling widgets
+        sframe = self["structure frame"] = ttk.LabelFrame(
+            self["frame"], text="Configuration Handling", labelanchor=tk.N
+        )
+        row = 0
+        widgets = []
+        for key in ("structure handling", "configuration name"):
+            self[key] = P[key].widget(sframe)
+            self[key].grid(row=row, column=0, sticky=tk.EW)
+            widgets.append(self[key])
+            row += 1
+        sw.align_labels(widgets, sticky=tk.E)
 
         self.logger.debug("Finished creating the dialog")
 
@@ -81,6 +101,8 @@ class TkOptimization(dftbplus_step.TkEnergy):
         row = 0
         self["optimization frame"].grid(row=row, column=1, sticky=tk.EW)
         row += 1
+        self["structure frame"].grid(row=row, column=0, columnspan=2)
+        row += 1
 
         # And the widgets in our frame
         self.reset_optimization_frame()
@@ -88,27 +110,7 @@ class TkOptimization(dftbplus_step.TkEnergy):
         return row
 
     def reset_optimization_frame(self):
-        """Layout the optimization frame according to the current values.
-
-            SD                   CG                  gDIIS                LBFGS              FIRE
-        ------------------   -------------------  -------------------  -------------------  --------
-        MovedAtoms           MovedAtoms           MovedAtoms           MovedAtoms           TimeStep
-        MaxForceComponent    MaxForceComponent    MaxForceComponent    MaxForceComponent
-        MaxSteps             MaxSteps             MaxSteps             MaxSteps
-        OutputPrefix         OutputPrefix         OutputPrefix         OutputPrefix
-        AppendGeometries     AppendGeometries     AppendGeometries     AppendGeometries
-        Constraints          Constraints          Constraints          Constraints
-        LatticeOpt           LatticeOpt           LatticeOpt           LatticeOpt
-        FixAngles            FixAngles            FixAngles            FixAngles
-        FixLengths
-        Isotropic            Isotropic            Isotropic            Isotropic
-        Pressure             Pressure             Pressure             Pressure
-        MaxAtomStep          MaxAtomStep                               MaxAtomStep
-        MaxLatticeStep       MaxLatticeStep       MaxLatticeStep       MaxLatticeStep
-        ConvergentForcesOnly ConvergentForcesOnly ConvergentForcesOnly ConvergentForcesOnly
-        StepSize                                  Alpha                Memory
-                                                  Generations          LineSearch
-        """  # noqa: E501
+        """Layout the optimization frame according to the current values."""
         frame = self["optimization frame"]
         for slave in frame.grid_slaves():
             slave.grid_forget()
@@ -120,46 +122,51 @@ class TkOptimization(dftbplus_step.TkEnergy):
 
         row = 0
 
-        w = self["optimization method"]
-        w.grid(row=row, column=0, columnspan=2, sticky=tk.EW)
+        w = self["LatticeOpt"]
+        w.grid(row=row, column=0, columnspan=3, sticky=tk.W)
         widgets.append(w)
         row += 1
 
-        if method == "Steepest descents":
-            w = self["StepSize"]
-            w.grid(row=row, column=1, sticky=tk.EW)
-            widgets1.append(w)
-            row += 1
-        elif "gDIIS" in method:
-            w = self["Alpha"]
-            w.grid(row=row, column=1, sticky=tk.EW)
-            widgets1.append(w)
-            row += 1
+        w = self["optimization method"]
+        w.grid(row=row, column=0, columnspan=3, sticky=tk.W)
+        widgets.append(w)
+        row += 1
 
-            w = self["Generations"]
-            w.grid(row=row, column=1, sticky=tk.EW)
+        if method == "Rational Function":
+            w = self["DiagLimit"]
+            w.grid(row=row, column=1, columnspan=1, sticky=tk.W)
             widgets1.append(w)
             row += 1
         elif "LBFGS" in method:
             w = self["Memory"]
-            w.grid(row=row, column=1, sticky=tk.EW)
+            w.grid(row=row, column=1, columnspan=1, sticky=tk.W)
             widgets1.append(w)
             row += 1
-
-            w = self["LineSearch"]
-            w.grid(row=row, column=1, sticky=tk.EW)
-            widgets1.append(w)
-            row += 1
-
+        elif "FIRE" in method:
+            for widget in (
+                "StepSize",
+                "nMin",
+                "aPar",
+                "fInc",
+                "fDec",
+                "fAlpha",
+            ):
+                w = self[widget]
+                w.grid(row=row, column=1, columnspan=1, sticky=tk.W)
+                widgets1.append(w)
+                row += 1
+            sw.align_labels(widgets1, sticky=tk.E)
         for widget in (
             "MaxForceComponent",
             "MaxSteps",
-            "MaxAtomStep",
-            "stop_if_scc_fails",
         ):
             w = self[widget]
-            w.grid(row=row, column=0, columnspan=2, sticky=tk.EW)
+            w.grid(row=row, column=0, columnspan=3, sticky=tk.W)
             widgets.append(w)
             row += 1
 
+        sw.align_labels(widgets, sticky=tk.E)
+
+        frame.columnconfigure(0, minsize=50)
+
         return row
